@@ -9,6 +9,7 @@ from tests.test_station import suite as station_suite
 from tests.test_cartography import suite as cartography_suite
 from tests.test_status import suite as status_suite
 from tests.test_geofinder import suite as geofinder_suite
+from tests.test_grabber import suite as grabber_suite
 
 db_connection('sqlite:///:memory:')
 
@@ -17,6 +18,7 @@ global_test_suite = unittest.TestSuite([models_suite,
                                         station_suite,
                                         cartography_suite,
                                         status_suite,
-                                        geofinder_suite,])
+                                        geofinder_suite,
+                                        grabber_suite,])
 
 
