@@ -33,6 +33,17 @@ class StationInformationTestCase(unittest.TestCase):
         station = StationInformation.update_or_create(values, surrogate=False)
         self.assertEquals(StationInformation.query.count(), 2)
         self.assertEquals(station.postal_code, '75000')
-        
+
+    def test_FullAddress(self):
+        values = {'id': 42,
+                  'address': '1 rue Kennedy',
+                  'postal_code': '94200',
+                  'city': 'Paris',
+                  'lat': '42.000000000',
+                  'lng': '42.000000000',
+                  'opened': True,
+                  'bonus': False}
+        station = StationInformation.update_or_create(values, surrogate=False)
+        self.assertEquals(station.full_address, '1 rue Kennedy, 94200 Paris')
         
 suite = unittest.TestLoader().loadTestsFromTestCase(StationInformationTestCase)
