@@ -12,6 +12,8 @@ XML_URL_DATA_STATION = config.get('XML', 'url_data_station')
 XML_URL_STATUS_STATION = config.get('XML', 'url_status_station')
 
 STATION_STATUS_RECENT = config.getint('STATION', 'status_recent')
+STATION_ALMOST_FULL = config.getint('STATION', 'almost_full')
+STATION_ALMOST_EMPTY = config.getint('STATION', 'almost_empty')
 
 DATABASE_URI = config.get('DATABASE', 'uri')
 DATABASE_ECHO = config.getboolean('DATABASE', 'echo')
